@@ -96,13 +96,14 @@ int ip_in_range (const char *ip);
 int ptr2int(char *ptr);
 int str2int (const char *date);
 int str_inarray (const char *s, const char *arr[], int size);
-int str_to_time (const char *str, const char *fmt, struct tm *tm);
+int str_to_time (const char *str, const char *fmt, struct tm *tm, int tz);
 int valid_output_type (const char *filename);
 off_t file_size (const char *filename);
 size_t append_str (char **dest, const char *src);
 uint32_t djb2(const unsigned char *str);
 uint32_t ip_to_binary (const char *ip);
 void genstr(char *dest, size_t len);
+void set_tz (void);
 void strip_newlines (char *str);
 void xstrncpy (char *dest, const char *source, const size_t dest_size);
 
